@@ -16,5 +16,5 @@
 """Top-level package for Uploadgram."""
 
 __author__ = """SpEcHIDe"""
-__email__ = "spechide@shrimadhavUK.me"
-__version__ = "0.1.5"
+__email__ = "uploADGRam@shrimadhavUK.me"
+__version__ = "0.1.7"
